[GitHub Pages](https://jameskabbes.github.io/the_garden/)

# the_garden
A build of commonly-used open-source tools

# Project Description
A collection of Python repositories used collectively to ease the pains of team development.

# First-Time Setup
Follow along for first-time setup.

## 1. Install Git on Anaconda Prompt
Inside Anaconda Prompt, install Git. (if you have not done so already)
```
conda install -c anaconda git
```

## 2. Navigate to a Handy Folder
Inside Anaconda Prompt, navigate to a directory on your machine that will be good for holding repositories

For example:
```
cd C:/Users/e150445/Documents/Repos
```

## 3. Clone the Repository
Inside Anaconda Prompt at your selected directory, clone the GitHub repo.
```
git clone https://github.com/jameskabbes/the_garden.git
```

## 4. Navigate into the Directory
Inside Anaconda Prompt in the directory for your repositories, navigate into the_garden
```
cd the_garden
```

## 5. Run the script main_garden.py
Run the setup script.
```
python first_time_setup.py
```



# Author(s)
James Kabbes